@@ -42,6 +42,8 @@ expected_schema = {
             },
             "ValidationError": {
                 "properties": {
+                    "ctx": {"title": "Context", "type": "object"},
+                    "input": {"title": "Input"},
                     "loc": {
                         "items": {"anyOf": [{"type": "string"}, {"type": "integer"}]},
                         "title": "Location",
