@@ -1,7 +1,6 @@
 import importlib
 
 import pytest
-from dirty_equals import IsDict
 from fastapi.testclient import TestClient
 
 
@@ -29,29 +28,16 @@ def test_post_invalid_body(client: TestClient):
     data = {"foo": 2.2, "3": 3.3}
     response = client.post("/index-weights/", json=data)
     assert response.status_code == 422, response.text
-    assert response.json() == IsDict(
-        {
-            "detail": [
-                {
-                    "type": "int_parsing",
-                    "loc": ["body", "foo", "[key]"],
-                    "msg": "Input should be a valid integer, unable to parse string as an integer",
-                    "input": "foo",
-                }
-            ]
-        }
-    ) | IsDict(
-        # TODO: remove when deprecating Pydantic v1
-        {
-            "detail": [
-                {
-                    "loc": ["body", "__key__"],
-                    "msg": "value is not a valid integer",
-                    "type": "type_error.integer",
-                }
-            ]
-        }
-    )
+    assert response.json() == {
+        "detail": [
+            {
+                "type": "int_parsing",
+                "loc": ["body", "foo", "[key]"],
+                "msg": "Input should be a valid integer, unable to parse string as an integer",
+                "input": "foo",
+            }
+        ]
+    }
 
 
 def test_openapi_schema(client: TestClient):
@@ -112,6 +98,8 @@ def test_openapi_schema(client: TestClient):
                         },
                         "msg": {"title": "Message", "type": "string"},
                         "type": {"title": "Error Type", "type": "string"},
+                        "input": {"title": "Input"},
+                        "ctx": {"title": "Context", "type": "object"},
                     },
                 },
                 "HTTPValidationError": {
