@@ -1,23 +1,38 @@
+import importlib
+
+import pytest
 from fastapi.testclient import TestClient
 
-from docs_src.response_model.tutorial003_02_py39 import app
-
-client = TestClient(app)
+from ...utils import needs_py310
 
 
-def test_get_portal():
+@pytest.fixture(
+    name="client",
+    params=[
+        pytest.param("tutorial003_05_py39"),
+        pytest.param("tutorial003_05_py310", marks=needs_py310),
+    ],
+)
+def get_client(request: pytest.FixtureRequest):
+    mod = importlib.import_module(f"docs_src.response_model.{request.param}")
+
+    client = TestClient(mod.app)
+    return client
+
+
+def test_get_portal(client: TestClient):
     response = client.get("/portal")
     assert response.status_code == 200, response.text
     assert response.json() == {"message": "Here's your interdimensional portal."}
 
 
-def test_get_redirect():
+def test_get_redirect(client: TestClient):
     response = client.get("/portal", params={"teleport": True}, follow_redirects=False)
     assert response.status_code == 307, response.text
     assert response.headers["location"] == "https://www.youtube.com/watch?v=dQw4w9WgXcQ"
 
 
-def test_openapi_schema():
+def test_openapi_schema(client: TestClient):
     response = client.get("/openapi.json")
     assert response.status_code == 200, response.text
     assert response.json() == {
